gnucash unstable: bugfix gnc_ui_new_account_window

Geert Janssens gjanssens at code.gnucash.org
Fri Mar 2 12:01:25 EST 2018


Updated	 via  https://github.com/Gnucash/gnucash/commit/2d983c67 (commit)
	from  https://github.com/Gnucash/gnucash/commit/e4884cdf (commit)



commit 2d983c6703a5133333660a8729ab5bbd598f500f
Author: Christopher Lam <christopher.lck at gmail.com>
Date:   Sat Mar 3 00:22:07 2018 +0800

    bugfix gnc_ui_new_account_window
    
    parent -> parent_acct
    fixes bug introduced in c76efd656ecdd77571102af57e936fc4ce4be97b

diff --git a/gnucash/gnome-utils/dialog-account.c b/gnucash/gnome-utils/dialog-account.c
index 3bd0827..9c41dca 100644
--- a/gnucash/gnome-utils/dialog-account.c
+++ b/gnucash/gnome-utils/dialog-account.c
@@ -1892,14 +1892,14 @@ gnc_ui_edit_account_window(GtkWindow *parent, Account *account)
  * opens up a window to create a new account
  *
  * Args:    book - containing book for the new account
  *        parent - The initial parent for the new account (optional)
  */
 void
 gnc_ui_new_account_window (GtkWindow *parent, QofBook *book,
                            Account *parent_acct)
 {
     g_return_if_fail(book != NULL);
-    if (parent && book)
+    if (parent_acct && book)
         g_return_if_fail(gnc_account_get_book(parent_acct) == book);
 
     gnc_ui_new_account_window_internal (parent, book, parent_acct, NULL, NULL,
@@ -1892,14 +1892,14 @@ gnc_ui_edit_account_window(GtkWindow *parent, Account *account)
  *
  * Args:    book - containing book for the new account
- *        parent - The initial parent for the new account (optional)
+ *   parent_acct - The initial parent for the new account (optional)
  */
 void



Summary of changes:
 gnucash/gnome-utils/dialog-account.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)



More information about the gnucash-changes mailing list